      SUBROUTINE AUTOCORR(X,N,IP,A,SIG2)
C   This program implements the autocorrelation method
C   of linear prediction for estimation of the AR parameters.
C   The equations are solved using the Levinson recursion.
C   See (7.3)-(7.5).
C
C   Input Parameters:
C         
C     X    - Complex array of dimension Nx1 of data points
C     N    - Number of data points
C     IP   - AR model order desired
C
C   Output Parameters:
C
C     A    - Complex array of dimension IPx1 of AR filter 
C            parameter estimates arranged as A(1) to A(IP)
C     SIG2 - Excitation white noise variance estimate
C
C   External Subroutines:
C    
C     CORRELATION - see Appendix 4D
C     LEVINSON    - see Appendix 6B
C
C   Notes: 
C
C     The calling program must dimension the arrays X,A.  
C     The arrays R,AA,RHO must be dimensioned greater than or equal 
C     to the variable dimensions shown.  The array AA in LEVINSON
C     must be dimensioned to agree with dimensions of AA in this
C     program.
C
C   Verification Test Case:
C
C     If the complex test data listed in Appendix 1.A is input
C     as X, with N=32, and IP=10, then the output should be
C       A(1) = ( 6.03004E-02,-4.09581E-02)
C       A(2) = (-0.66814    ,-6.09021E-02)
C       A(3) = (-0.36291    , 2.92395E-02)
C       A(4) = ( 0.43211    , 8.43889E-02)
C       A(5) = (-0.11293    , 7.85218E-03)
C       A(6) = ( 0.27237    ,-7.58821E-02)
C       A(7) = ( 0.13614    ,-3.52657E-02)
C       A(8) = ( 1.56604E-02, 2.54710E-02)    
C       A(9) = (-5.53038E-02, 2.44507E-02)
C       A(10)= ( 0.15153    ,-1.92422E-02)
C       SIG2 =  1.86565
C     for a DEC VAX 11/780.
C  
      COMPLEX X(1),A(1),R(IP+1),AA(IP,IP)
      DIMENSION RHO(IP)
C   Compute samples of biased autocorrelation estimator (7.4)
      MODE=1
      LAG=IP+1
      CALL CORRELATION(N,LAG,MODE,X,X,R)
C   Solve Yule-Walker equations using Levinson recursion (7.3),(7.5)
      CALL LEVINSON(R,IP,A,AA,RHO)
      SIG2=RHO(IP)
      RETURN
      END



