      SUBROUTINE BURG(X,N,IP,A,SIG2)
C   This program implements the Burg method for
C   estimation of the AR parameters (7.39)-(7.41).
C
C   Input Parameters:
C
C     X    - Complex array of dimension Nx1 of data points
C     N    - Number of data points
C     IP   - AR model order desired
C   
C   Output Parameters:
C
C     A    - Complex array of dimension IPx1 of AR filter
C            parameter estimates arranged as A(1) to A(IP)
C     SIG2 - Excitation white noise variance estimate
C
C   Notes: 
C
C     The calling program must dimension the X,A arrays.
C     The arrays EFK,EFK1,EBK,EBK1,AA,RHO must be 
C     dimensioned greater than or equal to the variable
C     dimensions shown.
C
C   Verification Test Case:
C
C     If the complex test data listed in Appendix 1.A is input
C     as X, with N=32, and IP=10, then the output should be
C       A(1) = (-0.10964, 9.80833E-02)
C       A(2) = (-1.07989,-8.23723E-02)
C       A(3) = (-0.16670,-7.09936E-02)
C       A(4) = ( 0.86892, 0.14021    )
C       A(5) = (-0.60076,-3.46992E-02)
C       A(6) = ( 0.34997,-0.34456    )
C       A(7) = ( 0.59898, 0.15030    )
C       A(8) = (-0.20271, 0.34466    )    
C       A(9) = (-0.50447,-3.14139E-02)
C       A(10)= ( 0.37516,-0.18268    )
C       SIG2 = 0.16930
C     for a DEC VAX 11/780.
C  
      COMPLEX X(1),A(1),EFK(N),EBK(N),EFK1(N),EBK1(N),
     * AA(IP,IP),SUMN,SUMD
      DIMENSION RHO(IP)
C   Compute the estimate of the autocorrelation at lag zero (7.39)
      RHO0=0.
      DO 10 I=1,N
10    RHO0=RHO0+CABS(X(I))**2/N
C   Initialize the forward and backward prediction errors (7.39)
      DO 20 I=2,N
      EFK1(I)=X(I)
20    EBK1(I-1)=X(I-1)
C   Begin recursion
      DO 80 K=1,IP
C   Compute the reflection coefficient estimate (7.40)
      SUMN=(0.,0.)
      SUMD=(0.,0.)
      DO 30 I=K+1,N
      SUMN=SUMN+EFK1(I)*CONJG(EBK1(I-1))
30    SUMD=SUMD+CABS(EFK1(I))**2+CABS(EBK1(I-1))**2
      AA(K,K)=-2.*SUMN/SUMD
C   Update the prediction error power (7.40)
      IF(K.EQ.1)RHO(K)=(1.-CABS(AA(K,K))**2)*RHO0
      IF(K.GT.1)RHO(K)=(1.-CABS(AA(K,K))**2)*RHO(K-1)
      IF(IP.EQ.1)GO TO 90
      IF(K.EQ.1)GO TO 50
C   Update the prediction error filter coefficients (7.40)
      DO 40 J=1,K-1
40    AA(J,K)=AA(J,K-1)+AA(K,K)*CONJG(AA(K-J,K-1))
C   Update the forward and backward prediction errors (7.41)
50    DO 60 I=K+2,N
      EFK(I)=EFK1(I)+AA(K,K)*EBK1(I-1)
60    EBK(I-1)=EBK1(I-2)+CONJG(AA(K,K))*EFK1(I-1)
      DO 70 I=K+2,N
      EFK1(I)=EFK(I)
70    EBK1(I-1)=EBK(I-1)
80    CONTINUE
C   Find final values of the prediction error power,
C   which is the white noise variance estimate, and the
C   prediction coefficients, which are the AR filter
C   parameter estimates
90    SIG2=RHO(IP)
      DO 100 I=1,IP
100   A(I)=AA(I,IP)
      RETURN
      END


