      SUBROUTINE CORRELATION(N,LAG,MODE,X,Y,R)
C   This program computes either the unbiased or biased complex
C   correlation estimates between arrays X and Y of complex data
C   samples.  If X=Y, then the estimate of the autocorrelation, 
C   rxx[k] for k=0,1,...,LAG-1, is computed (see (4.20)); otherwise 
C   the estimate of the crosscorrelation, rxy[k] for k=0,1,...,LAG-1,
C   is computed.  If the crosscorrelation estimate is desired for 
C   negative lags, then the relation rxy[-k]=ryx[k]* may be used 
C   (see (3.44)).  Hence, the X and Y arrays need only be interchanged
C   before calling this program and the output crosscorrelation 
C   samples complex conjugated.
C
C   Input Parameters:
C
C     N    - Number of data samples in complex arrays X and Y
C     LAG  - Number of correlation samples desired
C     MODE - Set equal to 0 for unbiased estimates; otherwise
C            biased estimates are computed
C     X    - Complex array of dimension Nx1 of data samples
C     Y    - Complex array of dimension Nx1 of data samples
C
C   Output Parameters:
C    
C     R    - Complex array of dimension NLAGx1 of correlation 
C            estimates where R(1),R(2),...,R(LAG) correspond to
C            r[0],r[1],...,r[LAG-1]
C
C   Notes:
C
C     The calling program must dimension arrays X,Y,R.
C
C   Verification Test Case:
C
C     If N=5, LAG=3, MODE=1, and
C       X(1)=( 1., 0.)  Y(1)=( 1.,0.)
C       X(2)=( 0., 1.)  Y(2)=(-1.,0.)
C       X(3)=(-1., 0.)  Y(3)=( 1.,0.)
C       X(4)=( 0.,-1.)  Y(4)=(-1.,0.)
C       X(5)=( 1., 0.)  Y(5)=( 1.,0.)
C     then the output should be
C       R(1)=(0.20000,0.00000)
C       R(2)=(0.00000,0.00000)
C       R(3)=(0.00000,0.20000)
C     for a DEC VAX 11/780.
C     
      COMPLEX X(1),Y(1),R(1),SUM
      DO 20 K=0,LAG-1
      NK=N-K
      SUM=(0.,0.)
      DO 10 J=1,NK
10    SUM=SUM+CONJG(X(J))*Y(J+K)
      IF(MODE.EQ.0)R(K+1)=SUM/(N-K)
      IF(MODE.NE.0)R(K+1)=SUM/N
20    CONTINUE
      RETURN
      END
    
