      SUBROUTINE DURBIN(X,N,IQ,L,B,SIG2)
C
C   This program implements Durbin's method of estimating
C   the MA parameters of a complex time series.  See Section
C   8.4 for a description based on real data and the summary
C   at the end of that section.  The modifications for complex
C   data are only in the definition of the autocorrelation 
C   estimator for complex data.
C
C   Input Parameters:
C
C     X    - Complex array of dimension Nx1 of data points
C     N    - Number of complex data points
C     IQ   - Desired MA model order
C     L    - Large AR model order (N/5 usually works well)
C
C   Output Parameters:
C
C     B    - Complex array of dimension IQx1 of MA filter
C            parameter estimates
C     SIG2 - Excitation white noise variance estimate
C
C   External Subroutines:
C
C     CORRELATION - see Appendix 4D
C     LEVINSON    - see Appendix 6B
C     AUTOCORR    - see Appendix 7B
C
C   Notes: 
C
C     The calling program must dimension arrays X,B.  The arrays
C     A,AP must be dimensioned greater than or equal to the
C     variable dimensions shown.  The arrays R,AA,RHO in AUTOCORR
C     must be dimensioned greater than or equal to L+1,LxL, and
C     L, respectively.  The array AA in Levinson must be dimensioned
C     to agree with dimensions of AA in AUTOCORR.
C
C   Verification Test Case:
C
C     If the complex test data listed in Appendix 1.A is input
C     as X, with N=32, IQ=10, and L=15, then the 
C     output should be
C       B(1) = (-4.70956E-02, 4.61267E-02)
C       B(2) = ( 0.56001    , 5.76182E-02)
C       B(3) = ( 0.22638    , 2.82898E-02)
C       B(4) = (-1.46033E-02, 8.90383E-03)
C       B(5) = ( 0.36459    , 4.33258E-03)
C       B(6) = (-0.27950    , 2.51802E-02)
C       B(7) = ( 0.14134    , 1.90398E-02)
C       B(8) = (-0.10563    ,-3.48616E-02)    
C       B(9) = (-5.12997E-02,-4.19190E-02)
C       B(10)= ( 1.87891E-02,-1.10760E-02)
C       SIG2 = 1.83942
C     for a DEC VAX 11/780.
C
      COMPLEX X(1),B(1),A(L),AP(L+1)
C   Fit a large order AR model to the data using autocorrelation method
      CALL AUTOCORR(X,N,L,A,SIG2)
C   Use large order AR parameter estimates as new data
      L1=L+1
      AP(1)=(1.,0.)
      DO 20 I=2,L1
20    AP(I)=A(I-1)
C   Use autocorrelation method to generate MA parameter estimates (8.9)
      CALL AUTOCORR(AP,L1,IQ,B,PB)
      RETURN
      END




