      SUBROUTINE FFT(X,M,INVRS)
C
C   This program computes the fast Fourier transform of
C   an array of complex data using a decimation-in-time
C   FFT.  See Oppenheim and Schafer [1975] for further details.
C
C   Input Parameters:
C
C     X     - Complex array of dimension 2**Mx1 of data samples
C     M     - Power of two for FFT size
C     INVRS - Set equal to:  1 for forward Fourier transform
C                           -1 for inverse Fourier transform
C
C   Output Parameters:
C
C     X     - Complex array of dimension 2**Mx1 of Fourier
C             transform values
C
C   Notes:
C
C     The calling program must dimension the complex array X 
C     greater than or equal to 2**Mx1. The complex array Y must
C     be dimensioned greater than or equal to 2**Mx1.
C
C   Verification Test Case:
C
C     If M=3, INVRS=1, and
C       X(1)=X(5)=( 1., 0.)
C       X(2)=X(6)=( 0., 1.)
C       X(3)=X(7)=(-1., 0.)
C       X(4)=X(8)=( 0.,-1.)
C     then the output should be
C       X(1)=(0.00000, 0.00000)      X(5)=(0.00000,    0.00000)
C       X(2)=(0.00000, 0.00000)      X(6)=(0.00000,    0.00000)
C       X(3)=(8.00000,-1.74845E-07)  X(7)=(0.00000,1.74845E-07)
C       X(4)=(0.00000, 0.00000)      X(8)=(0.00000,    0.00000)
C     for a DEC VAX 11/780.
C       
      COMPLEX X(1),Y(2**M),W,SAVE
      N=2**M
C   Put the data into bit reversed form
      Y(1)=X(1)
      DO 20 I=2,N
      NUM=I-1
      J=0
      L=N
      DO 10 K=1,M
      L=L/2
      IF(NUM.LT.L)GO TO 10
      J=J+2**(K-1)
      NUM=NUM-L
10    CONTINUE
      Y(I)=X(J+1)
20    CONTINUE
C   Begin computation of FFT
      PI=4.*ATAN(1.)
      LDFT=1
      NDFT=N
      DO 50 K=1,M
      LDFT=2*LDFT
      NDFT=NDFT/2
      DO 40 I=1,NDFT
      DO 30 J=1,LDFT/2
C   Determine twiddle factor
      ARG=-(2.*PI*INVRS)*(J-1.)/LDFT
      W=CMPLX(COS(ARG),SIN(ARG))
C   Determine indices for next butterfly to be computed
      NP=J+LDFT*(I-1)
      NQ=NP+LDFT/2
C   Compute butterfly for the Ith DFT in stage K
      SAVE=Y(NP)+W*Y(NQ)
      Y(NQ)=Y(NP)-W*Y(NQ)
30    Y(NP)=SAVE
40    CONTINUE
50    CONTINUE
C   Divide array values by N if inverse FFT desired 
      DO 60 I=1,N
      IF(INVRS.EQ.1)X(I)=Y(I)
60    IF(INVRS.EQ.-1)X(I)=Y(I)/N
      RETURN
      END

