      SUBROUTINE STEPDOWN(IP,A,SIG2,AA,RHO0,RHO)
C
C   This program implements the step-down procedure to find the
C   coefficients and prediction error powers for all the lower
C   order predictors given the coefficients and prediction
C   error power for the IPth order linear predictor or
C   equivalently given the filter parameters and white noise 
C   variance of an IPth order AR model.  See (6.51) and (6.52).
C
C   Input Parameters:
C
C     IP   - AR model order (must be 2 or greater)
C     A    - Complex array of dimension IPx1 of AR parameters
C            arranged as A(1) to A(IP)
C     SIG2 - Variance of excitation noise of AR model of order
C            IP or equivalently the prediction error power of
C            the optimal linear predictor of order IP
C
C   Output Parameters:
C
C     AA   - Complex array of dimension IPxIP of prediction
C            coefficients where AA(I,J) is the Ith coeff-
C            icient of the Jth order predictor
C     RHO0  - Zeroth lag of ACF
C     RHO   - Real vector of dimension IPx1 of prediction error
C             powers where RHO(J) is the prediction error power
C             for the Jth order predictor
C
C   Notes: 
C
C     The calling program must dimension the arrays A,AA,RHO.
C     The array AA must be dimensioned in the calling program
C     to be greater than or equal to the variable dimensions
C     shown and in this program to agree with calling program 
C     dimensions.
C
C   Verfication Test Case:
C
C     If IP=3, A(1)=(0.625,0.375), A(2)=(0.5,-0.375), A(3)=(0.5,0.),
C     and SIG2=0.328125, then the output should be
C       AA(1,1)=(0.50000,0.50000), AA(1,2)=(0.50000,0.25000),
C       AA(2,2)=(0.25000,-0.25000), RHO0=0.99999, RHO(1)=0.50000,
C       RHO(2)=0.43750, RHO(3)=0.328125
C     for a DEC VAX 11/780.
C
      COMPLEX A(1),AA(IP,IP)
      DIMENSION RHO(1)
C   Initialize step-down by equating AR parameters to IPth
C   order prediction coefficients and prediction error power
      DO 10 I=1,IP
10    AA(I,IP)=A(I)
      RHO(IP)=SIG2
C   Begin step-down
      IP2=IP-1
      DO 30 J=1,IP2
      K=IP+1-J
      DEN=1.-CABS(AA(K,K))**2
C   Compute lower order prediction error power (6.52)
      RHO(K-1)=RHO(K)/DEN  
C   Compute lower order prediction coefficients (6.51)
      K1=K-1
      DO 20 I=1,K1
      AA(I,K-1)=(AA(I,K)-AA(K,K)*CONJG(AA(K-I,K)))/DEN   
20    CONTINUE
30    CONTINUE
C  Complete step-down by computing zeroth lag of ACF
      RHO0=RHO(1)/(1.-CABS(AA(1,1))**2)
      RETURN
      END


