      SUBROUTINE WGN(N,VAR,ISEED,W)
C
C   This program generates N samples of real white Gaussian
C   noise with zero mean and a specified variance.  M samples of
C   complex white Gaussian noise may be generated by calling   
C   this program to generate 2*M real samples and then concatenating 
C   the output samples as (W(2*I-1),W(2*I)) for I=1,2,...,M.
C
C   The random number generator used in this program is an 
C   intrinsic function on the DEC VAX 11/780 and requires a seed
C   number to start the generation.  The seed should be a large
C   positive and odd integer such as 69069.  For non VAX
C   computers this program may be used if the random number 
C   generator is replaced (See comments in code).
C
C   Input Parameters:
C
C     N     - Number of real white noise samples desired
C     VAR   - Variance of white noise samples desired
C     ISEED - Seed number for random number generator
C
C   Output Parameters:
C
C     W     - Real array of dimension Nx1 of white noise
C             samples
C
C   External Subroutines:
C
C     RAN   - Intrinsic function on DEC VAX 11/780.  For other
C             machines replace with random number generator
C             which generates uniformly distributed random
C             numbers on the interval [0,1].
C      
C   Notes:
C
C     The calling program must dimension the array W.
C
C   Verification Test Case:
C
C     If N=5, VAR=2.,and ISEED=69069, the output should be
C       W(1)=-1.70822, W(2)=-2.42586, W(3)=-1.59297,
C       W(4)=0.14068, W(5)=-2.16533
C     for a DEC VAX 11/780.  For non-VAX machines one should
C     replace line 10 of the subroutine RANDOM to input the
C     random numbers
C       W(1)=0.11072, W(2)=0.65235, W(3)=0.52763,
C       W(4)=0.48598, W(5)=0.16694, W(6)=0.40004
C     to test the WGN subroutine.
C
      DIMENSION W(1)
      PI=4.*ATAN(1.)
C   Add one to desired number of samples if N is odd
      M=N
      IF(MOD(N,2).NE.0)M=N+1
C   Generate M independent and uniformly distributed random
C   variables on [0,1]
      CALL RANDOM(M,VAR,ISEED,W)
      L=M/2
C   Convert uniformly distributed random variables to Gaussian
C   ones using Box-Mueller transform
      DO 10 I=1,L
      U1=W(2*I-1)
      U2=W(2*I)
      TEMP=SQRT(-2.*ALOG(U1))
      W(2*I-1)=TEMP*COS(2.*PI*U2)*SQRT(VAR)
10    W(2*I)=TEMP*SIN(2.*PI*U2)*SQRT(VAR)
      RETURN
      END
      SUBROUTINE RANDOM(M,VAR,ISEED,W)
      DIMENSION W(1)
      DO 10 I=1,M
C   For machines other than DEC VAX 11/780 replace RAN(ISEED)
C   with random number generator.
10    W(I)=RAN(ISEED)
      RETURN
      END

